@@ -13,7 +13,7 @@ use Struct::Path 0.80 qw(path path_delta);
 use Struct::Path::PerlStyle 0.80 qw(str2path path2str);
 use Term::ANSIColor qw(colored);
 
-sub VERSION() { '0.31' }
+our $VERSION = '0.38';
 
 my $JSON = JSON->new->canonical->allow_nonref;
 
@@ -40,13 +40,10 @@ sub check_args {
     my $self = shift;
 
     if ($self->{OPTS}->{show}) {
-        unless (@_) {
-            log_error { "At least one argument expected when --show used" };
-            return undef;
-        }
+        die_fatal "At least one argument expected when --show used", 1
+            unless (@_);
     } elsif (@_ < 2) {
-        log_error { "At least two arguments expected for diff" };
-        return undef;
+        die_fatal "At least two arguments expected for diff", 1;
     }
 
     return $self;
@@ -55,7 +52,9 @@ sub check_args {
 sub configure {
     my $self = shift;
 
-    $self->{OPTS}->{colors} = -t STDOUT ? 1 : 0
+    $self->SUPER::configure();
+
+    $self->{OPTS}->{colors} = $self->{TTY}
         unless (defined $self->{OPTS}->{colors});
 
     for (@{$self->{OPTS}->{grep}}, @{$self->{OPTS}->{ignore}}) {
@@ -108,6 +107,13 @@ sub diff {
         noU => $self->{OPTS}->{full} ? 0 : 1,
     );
 
+    # retrieve result from wrapper (see load() for more info)
+    if (exists $diff->{D}) {
+        $diff = $diff->{D}->[0];
+    } elsif (exists $diff->{U}) {
+        $diff->{U} = $diff->{U}->[0];
+    }
+
     if ($self->{OPTS}->{ofmt} eq 'term') {
         $self->diff_term($diff) or return undef;
     }
@@ -175,7 +181,7 @@ sub diff_term {
                 pop @new; # -"-
             }
 
-            ($o, $n) = _lcsidx2ranges(Algorithm::Diff::LCSidx \@old, \@new);
+            ($o, $n) = _lcsidx2ranges(Algorithm::Diff::LCSidx(\@old, \@new));
             ($po, $pn) = (0, 0);
 
             while (@{$o}) {
@@ -276,20 +282,26 @@ sub dump_term {
 
 sub exec {
     my $self = shift;
-
-    $self->check_args(@{$self->{ARGV}}) or die_fatal undef, 1;
-
     my @items;
 
     while (@{$self->{ARGV}}) {
         my $name = shift @{$self->{ARGV}};
-        my $data = $self->load($name) or die_fatal undef, 1;
+        my $data = $self->load($name);
 
         my $diff;
 
         if ($self->{OPTS}->{show}) {
             $self->print_term_header($name);
-            $diff = $data;
+            $diff = $data->[0];
+
+            if (my @errs = Struct::Diff::valid_diff($diff)) {
+                while (@errs) {
+                    my ($path, $type) = splice @errs, 0, 2;
+                    log_error { "$name: $type " . path2str($path) };
+                }
+
+                die_fatal "Diff validation failed", 1;
+            }
         } else {
             push @items, { name => $name, data => $data };
             next unless (@items > 1);
@@ -315,16 +327,17 @@ sub exec {
 sub load {
     my $self = shift;
 
-    my $data = $self->load_struct($_[0], $self->{OPTS}->{ifmt})
-        or return undef;
+    my @data = $self->load_struct($_[0], $self->{OPTS}->{ifmt});
 
-    ($data) = $self->grep($self->{OPTS}->{grep}, $data)
+    # array used to indicate absent value for grep result
+    @data = $self->grep($self->{OPTS}->{grep}, $data[0])
         if (@{$self->{OPTS}->{grep}});
 
-    map { path($data, $_, delete => 1) } @{$self->{OPTS}->{ignore}}
-        if (ref $data);
+    if (@data and ref $data[0]) {
+        map { path($data[0], $_, delete => 1) } @{$self->{OPTS}->{ignore}}
+    }
 
-    return $data;
+    return \@data;
 }
 
 sub print_brief_block {
@@ -380,7 +393,7 @@ sub print_term_block {
 sub print_term_header {
     my ($self, @names) = @_;
 
-    return unless (-t STDOUT); # don't dump to pipes
+    return if (!$self->{TTY} or $self->{OPTS}->{quiet});
 
     my $header = @names == 1 ? $names[0] :
         "--- a: $names[0] \n+++ b: $names[1]";
