@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 use parent 'App::NDTools::NDTool';
 
-use Getopt::Long qw(:config bundling pass_through);
+use Getopt::Long qw(GetOptionsFromArray :config bundling);
 use Log::Log4Cli;
 use Module::Find qw(findsubmod);
 use App::NDTools::Slurp qw(s_decode s_dump s_encode);
@@ -13,11 +13,13 @@ use Struct::Diff 0.94 qw(diff split_diff);
 use Struct::Path 0.80 qw(path);
 use Struct::Path::PerlStyle 0.80 qw(str2path);
 
-sub VERSION() { '0.23' }
+our $VERSION = '0.26';
 
 sub arg_opts {
     my $self = shift;
 
+    Getopt::Long::Configure('pass_through');
+
     my %arg_opts = (
         $self->SUPER::arg_opts(),
         'builtin-format=s' => \$self->{OPTS}->{'builtin-format'},
@@ -133,10 +135,8 @@ sub exec {
         'version|V' => sub { print $self->VERSION . "\n"; exit 0 },
     );
 
-    my $p = Getopt::Long::Parser->new();
-    $p->configure('nopass_through'); # just to be sure
-    unless ($p->getoptionsfromarray($self->{ARGV}, @rest_opts)) {
-
+    Getopt::Long::Configure('nopass_through');
+    unless (GetOptionsFromArray($self->{ARGV}, @rest_opts)) {
         $self->usage;
         die_fatal "Unsupported opts passed", 1;
     }
